@@ -4,6 +4,7 @@ import boto3.s3.transfer
 import tqdm
 from typing import Union
 from . import utils as djsciops_utils
+import collections.abc
 
 
 def _generate_transfer_mapping(
@@ -65,7 +66,43 @@ def _generate_transfer_mapping(
     return file_paths, object_paths
 
 
-def upload_files(session, s3_bucket: str, source: str, destination: str):
+def list_files(
+    session,
+    s3_bucket: str,
+    s3_prefix: str,
+):
+    objects = [
+        dict(key=op.key, _size=op.size)
+        for op in session.s3.Bucket(s3_bucket).objects.filter(Prefix=s3_prefix)
+    ]
+    objects = sorted(objects, key=lambda o: o["key"])
+
+    tree = {}
+    for o in objects:
+        node = tree  # local node
+        levels = o["key"].split("/")
+        for level in levels:
+            node = node.setdefault(level, dict())
+            node["_size"] = (
+                o["_size"] + node["_size"] if "_size" in node else o["_size"]
+            )
+
+    def update(d):
+        for k, v in d.items():
+            if isinstance(v, collections.abc.Mapping) and len(v) > 1:
+                if k != "_size":
+                    size = d[k].pop("_size")
+                    d[k] = update(d.get(k, {}))
+            else:
+                d[k] = None
+        return d
+
+    return update(tree)
+
+
+def upload_files(
+    session, s3_bucket: str, source: Union[str, list], destination: Union[str, list]
+):
     djsciops_utils.log("axon copy", message_type="header")
     file_paths, object_paths = _generate_transfer_mapping(
         session=session, s3_bucket=s3_bucket, source=source, destination=destination
