@@ -3,6 +3,7 @@ from . import __version__ as version
 from . import authentication as djsciops_authentication
 from . import axon as djsciops_axon
 from . import settings as djsciops_settings
+import sys
 
 
 def djsciops(args: list = None):
@@ -36,8 +37,7 @@ def djsciops(args: list = None):
         type=str,
         help="Target directory in object store.",
     )
-
-    kwargs = vars(parser.parse_args(args or ["-h"]))
+    kwargs = vars(parser.parse_args(args if sys.argv[1:] else ["-h"]))
     config = djsciops_settings.get_config()
     if kwargs["command"] == "axon" and kwargs["subcommand"] == "upload":
         djsciops_axon.upload_files(
